==> qtquick3d-everywhere-src-6.1.1.zip: qtquick3d-everywhere-src-6.1.1/src/quick3d/qquick3dcustomcamera_p.h <==
/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Quick 3D.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QSSGCUSTOMCAMERA_H
#define QSSGCUSTOMCAMERA_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <QtQuick3D/private/qquick3dcamera_p.h>

QT_BEGIN_NAMESPACE

struct QSSGRenderCamera;
class Q_QUICK3D_EXPORT QQuick3DCustomCamera : public QQuick3DCamera
{
    Q_OBJECT
    Q_PROPERTY(QMatrix4x4 projection READ projection WRITE setProjection NOTIFY projectionChanged)

    QML_NAMED_ELEMENT(CustomCamera)
    QML_ADDED_IN_VERSION(1, 14)

public:
    QQuick3DCustomCamera();

    QMatrix4x4 projection() const;

public Q_SLOTS:
    void setProjection(const QMatrix4x4 &projection);

Q_SIGNALS:
    void projectionChanged();

protected:
    bool checkSpatialNode(QSSGRenderCamera *camera) override;

private:
    QMatrix4x4 m_projection;
};

QT_END_NAMESPACE

#endif // QSSGCUSTOMCAMERA_H

==> qtquick3d-everywhere-src-6.2.1.zip: qtquick3d-everywhere-src-6.2.1/src/quick3d/qquick3dcustomcamera_p.h <==
/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Quick 3D.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QSSGCUSTOMCAMERA_H
#define QSSGCUSTOMCAMERA_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <QtQuick3D/private/qquick3dcamera_p.h>

QT_BEGIN_NAMESPACE

struct QSSGRenderCamera;
class Q_QUICK3D_EXPORT QQuick3DCustomCamera : public QQuick3DCamera
{
    Q_OBJECT
    Q_PROPERTY(QMatrix4x4 projection READ projection WRITE setProjection NOTIFY projectionChanged)

    QML_NAMED_ELEMENT(CustomCamera)

public:
    explicit QQuick3DCustomCamera(QQuick3DNode *parent = nullptr);

    QMatrix4x4 projection() const;

public Q_SLOTS:
    void setProjection(const QMatrix4x4 &projection);

Q_SIGNALS:
    void projectionChanged();

protected:
    QSSGRenderGraphObject *updateSpatialNode(QSSGRenderGraphObject *node) override;

private:
    QMatrix4x4 m_projection;
};

QT_END_NAMESPACE

#endif // QSSGCUSTOMCAMERA_H
